// This program  estimates the Gambia DSGE Model developed to analyse fiscal and monetary policy under
// domestic debt stress
//We consider three fiscal tax shocks, 2 Gvt spending shocks (current expenditure shock
//and capital expenditure shock). One monetary shock on interest rate following Taylor rule and technological shock (TFP).
//Domestic debt evolves as Gvt primary deficit increases. Therefore, the Gvt budget constraint considers that primary balance
//is equal to additional domestic debt.

// Declares the endogenous variables
var y, c, k, lab, w, z, r, pi, d, R, gc,gi, tc, tk, tw, s 	;	%	, pis
varexo  e_r, e_z, e_gc, e_gi, e_c, e_w, e_k   ;	  						                                             

parameters bet, theta, gam, rho, phipi, phiy,  rhor, rhogc, phigc, rhogi, phigi, rhoc, rhok, rhow , phic, phik, phiw, phidc, phidk, phidw ; 	//
	          

bet=0.90;              //87 discount factor (calibrated as equal to 1/(1+AVerage Saving rate over 10 years)
theta=0.33;         // capital share in outout ;
gam=1.5 ;            // Paramtre of elasticity of intertemporal substitution between leisure and labor 
rho=0.8;            // TFP: Productivity shoc autoregressive parameter   
rhor=0.80;              // Taylor rule AR parameter
phipi=1.5;             // Taylor rule, inflation parameter 
phiy=.125;             // Taylor rule, output gap parameter 
rhogc=0.17;
phigc=0.3;         %0.6 .11 ;
rhogi=0.5;          %0.6;
phigi=0.3;         %0.6;0.4
rhoc=0.8;           %0.61;
rhok=0.83;           %0.5;
rhow=0.5;           %0.3;
phic=1.4;          %0.05;
phik=1.4;          %0.1;
phiw=0.76;          %0.02;
phidc=0.3;          %0.15 
phidk=0.3;          %1.5
phidw=3;            %0.023


model;

y=z*(k(-1)^theta)*((lab)^(1-theta));
log(z)=rho*log(z(-1))+e_z;
w=(1-theta)*z*(k(-1)^theta)*((lab)^(-theta));
R=theta*z*(k(-1))^(theta-1)*(lab)^(1-theta);
(1+tc)*gam*c=(1-lab)*(1-tw)*w;
(1+tk)*c(+1)*(1+tc(+1))=bet*(1+tc)*c*R(+1);
bet*(1+r(+1))*(1+tc)*c*pi=c(+1)*(1+tc(+1))*pi(+1);
                                                                          

//Fiscal variables equations 

tc*c+tk*k +tw*w*lab+(d-d(-1))/pi-(gc+gi+r*(d(-1)/pi))=0;				
r=rhor*r(-1)+(1-rhor)*phipi*pi+(1-rhor)*phiy*y+e_r;                               //								                                                                      
y=c+k+gc+gi;
s=d/y;
gc=rhogc*gc(-1) + (1-rhogc)*phigc*s + e_gc;                                      // Gvt consumption expenditure
gi=rhogi*gi(-1) + (1-rhogi)*phigi*s + e_gi;
%log(gc)=rhogc*log(gc(-1)) + (1-rhogc)*log(phigc*s) + e_gc;                      // Gvt consumption expenditure
%log(gi)=rhogi*log(gi(-1)) + (1-rhogi)*log(phigi*s) + e_gi;
tc=rhoc*tc(-1) + (1-rhoc)*(phic*y+phidc*s(-1)) + e_c;                            //Tax on consumption
tk=rhok*tk(-1) + (1-rhok)*(phik*y +phidk*s(-1)) + e_k;                           //Tax on capital 
tw=rhow*tw(-1) + (1-rhow)*(phiw*y +phidw*s(-1)) + e_w;                           //Tax on import

end ;


initval;
y=0.70;          %2.743;                                                                                                                                 
k=0.13;         %0.793;                                                                                          
c=-0.05;        %-0.817;                                                                                                                   
lab=1.58;       %5.055;                                                                                                         
w=0.30;         %0.364;   
z=1;              
d=-4.08;        %0.92;                    						                                                                                                                                                                        
s=0.15;          %0.20;
r=0.111;                                                                                           									                                
pi=1;
R=1.72;         %1.142;    
gc=0.02;        %0.302;   
gi=0.02;        %1.097;                                                                                                         
tc=0.55;        %0.16;            %  ;                                                                       
tw=0.30;        %0.05;            % ;                                                               	
tk=0.55;        %0.03;            %;      
e_z=0.0;                                                                                            
e_r=0.0; 
e_gc=0;
e_gi=0;
e_c=0;
e_w=0;
e_k=0;                    
       
end;

steady;
check;

shocks;

var e_z;   stderr 0.01;
var e_r;   stderr 0.01;
var e_gc;  stderr 0.01;
var e_gi;  stderr 0.01;
var e_c;   stderr 0.01;
var e_k;   stderr 0.01;
var e_w;   stderr 0.01;

end;


varobs y;// , pi, d, r, gc, gi, k

estimated_params;
theta, beta_pdf, 0.33, 0.02;
bet, beta_pdf, 0.90, 0.001;
gam, gamma_pdf, 1.5, 0.005;
rho, beta_pdf, 0.8, 0.05;
rhor, beta_pdf, 0.8, 0.01;
rhogc, beta_pdf,  0.17, 0.1;
rhogi, beta_pdf,  0.5, 0.1;
rhoc, beta_pdf,  0.8, 0.1;
rhok, beta_pdf,  0.83, 0.1;
rhow, beta_pdf,  0.5, 0.1;
phipi, normal_pdf,  1.5, 0.25;
phiy, normal_pdf,  0.125, 0.05;
phigc, normal_pdf,  0.3, 0.1;
phigi, normal_pdf,  0.3, 0.1;
phic, gamma_pdf,  1.4, 0.15;
phik, gamma_pdf,  1.4, 0.25;
phiw, gamma_pdf,  0.76, 0.15;
phidc, normal_pdf,  0.3, 0.1;
phidk, normal_pdf,  0.3, 0.1;
phidw, normal_pdf,  3, 0.01;

end;

//estimation(datafile=data2, mh_replic=1500, mh_nblocks=2, mh_drop=0.45, mode_check) y, pi, gc, gi, s, d, r;

estimation(datafile='data2.xls', xls_sheet=data, xls_range=A1:G18)y, pi, gc, gi, s, d, r;  //, mh_replic=1500, mh_nblocks=2, mh_drop=0.45y, pi, gc, gi, s, d, r;

//estimation(datafile=simuldataMed902,  mh_replic=1500, mh_nblocks=2, mh_drop=0.45);

//mh_replic=1500, mh_nblocks=2, mh_drop=0.45, mh_jscale=0.8, mode_compute=4

